@@ -18,8 +18,8 @@
 
 // This file contains a base class for congruence-like classes.
 
-#ifndef LIBSEMIGROUPS_INCLUDE_CONG_INTF_HPP_
-#define LIBSEMIGROUPS_INCLUDE_CONG_INTF_HPP_
+#ifndef LIBSEMIGROUPS_CONG_INTF_HPP_
+#define LIBSEMIGROUPS_CONG_INTF_HPP_
 
 #include <cstddef>  // for size_t
 #include <memory>   // for shared_ptr
@@ -631,6 +631,7 @@ namespace libsemigroups {
 
     //! No doc
     void set_parent_froidure_pin(std::shared_ptr<FroidurePinBase>);
+    //! No doc
     void set_parent_froidure_pin(std::shared_ptr<FpSemigroupInterface>);
 
     //! No doc
@@ -642,6 +643,7 @@ namespace libsemigroups {
           std::make_shared<T>(prnt)));
     }
 
+    //! No doc
     template <typename T, typename SFINAE = void>
     auto set_parent_froidure_pin(T& prnt) ->
         typename std::enable_if<std::is_base_of<FpSemigroupInterface, T>::value,
@@ -766,4 +768,4 @@ namespace libsemigroups {
     static const std::string STRING_RIGHT;
   };
 }  // namespace libsemigroups
-#endif  // LIBSEMIGROUPS_INCLUDE_CONG_INTF_HPP_
+#endif  // LIBSEMIGROUPS_CONG_INTF_HPP_
